"""Logging definitions."""
from sphinx.util.logging import getLogger

logger = getLogger("sphinx_codeautolink")
warn_type = "codeautolink"
